@@ -1,11 +1,9 @@
 package Pcore::DBD::DDL::SQLite;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::DBD::DDL];
 
-no Pcore;
-
 sub schema_info_sql ($self) {
     my $table = $self->_schema_info_table;
 
