@@ -1,6 +1,6 @@
-package Pcore::SQLite v0.3.6;
+package Pcore::SQLite v0.4.0;
 
-use Pcore -class;
+use Pcore -dist, -class;
 
 1;
 __END__
